from django.apps import AppConfig


class AdminSiteSearchConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "admin_site_search"
    verbose_name = "django-admin-site-search"
